#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <time.h>

#define MINREAL -1024.0
#define MAXREAL 1024.0

#include <sys/time.h>

double gettime(void) {
   struct timeval tv;
   gettimeofday(&tv, NULL);
   return tv.tv_sec + 1e-6 * tv.tv_usec;
}

void matFillSimple(long M, long N, long *mat, long val) {
   long i, j;

   for(i = 0; i < M; i ++)
      for(j = 0; j < N; j ++)
         mat[i * N + j] = val;
}

void matFillRand(long M, long N, long *mat) {
   long i, j;

   for(i = 0; i < M; i ++)
      for(j = 0; j < N; j ++)
         mat[i * N + j] = (rand() / (double) RAND_MAX)*(MAXREAL - MINREAL) + MINREAL;
}

void matOddEvenCount(long M, long N, long *mat, long* result) {
   long i, j, odd = 0, even = 0;
     
   for(i = 0; i < M; i ++)
      for(j = 0; j < N; j ++) {
		 int t = mat[i * N + j] & 1;
		 odd += t;
		 even += !t;
	  }
	
	result[0] = even;
	result[1] = odd;
}

int main(int argc, char **argv) {
   long M, N, result[2];
   long *A;
   double t;

   srand(time(NULL));

   M = atoi(argv[1]);
   N = atoi(argv[2]);
   
   A = (long *) malloc(M * N * sizeof(long));
   
   //matFillSimple(M, N, A, 1);
   matFillRand(M, N, A);
   
   t = gettime();
   matOddEvenCount(M, N, A, result);
   t = gettime() - t;

   printf("Number of even: %ld\n", result[0]);
   printf("Number of odd: %ld\n", result[1]);
      
   fprintf(stdout, "%ld\t%lf\n", N, t);
   fflush(stdout);

   free(A);
   
   return EXIT_SUCCESS;
}
